@@ -3,8 +3,8 @@
 #include "uthash.h"
 
 typedef struct {
-  char a;
-  int b;
+    char a;
+    int b;
 } record_key_t;
 
 typedef struct {
@@ -13,10 +13,14 @@ typedef struct {
     UT_hash_handle hh;
 } record_t;
 
-int main(int argc, char *argv[]) {
-    record_t l, *p, *r, *records = NULL;
+int main(int argc, char *argv[])
+{
+    record_t l, *p, *r, *tmp, *records = NULL;
 
     r = (record_t*)malloc( sizeof(record_t) );
+    if (r == NULL) {
+        exit(-1);
+    }
     memset(r, 0, sizeof(record_t));
     r->key.a = 'a';
     r->key.b = 1;
@@ -27,7 +31,14 @@ int main(int argc, char *argv[]) {
     l.key.b = 1;
     HASH_FIND(hh, records, &l.key, sizeof(record_key_t), p);
 
-    if (p) printf("found %c %d\n", p->key.a, p->key.b);
+    if (p != NULL) {
+        printf("found %c %d\n", p->key.a, p->key.b);
+    }
+
+    HASH_ITER(hh, records, p, tmp) {
+        HASH_DEL(records, p);
+        free(p);
+    }
     return 0;
 }
 
