@@ -36,7 +36,7 @@ int main(int argc, char *argv[])
         if (name == NULL) {
             exit(-1);
         }
-        strncpy(name->bname,linebuf,sizeof(name->bname));
+        strcpy(name->bname, linebuf);
         DL_APPEND(head, name);
     }
     DL_SORT(head, namecmp);
