@@ -13,17 +13,16 @@ int main(int argc,char *argv[])
     int i;
     elt *head = NULL;
     elt elts[10];
-    char label[6];
+    char label[6] = "hello";
     for(i=0; i<10; i++) {
         elts[i].s = (char*)malloc(6UL);
-        strncpy(elts[i].s, "hello",6UL);
+        strcpy(elts[i].s, "hello");
         elts[i].s[0] = 'a' + i;
         printf("%d: %s\n", i, elts[i].s);
         HASH_ADD_KEYPTR(hh, head, elts[i].s, 6UL, &elts[i]);
     }
 
     /* look up each element and verify the result pointer */
-    strncpy(label, "hello", sizeof(label));
     for(i=0; i<10; i++) {
         elt *e;
         label[0] = 'a' + i;
